@@ -880,8 +880,14 @@ Entangled1Maurer2012 <- function() {
 	graph <- new("entangledMCP", subgraphs=list(graph1,graph2), weights=c(0.5,0.5))
 
 	attr(graph, "description") <- paste("Graph from Maurer and Bretz 2012",
-			"",
-			"Literature: Maurer, W., & Bretz, F. (2013). Memory and other properties of multiple test procedures generated by entangled graphs. Statistics in medicine, 32(10), 1739-1753.", sep="\n")
+	                                    "",
+	                                    "H1, H2: Period 1 primary hypotheses of no effect for endpoint (a) comparing low and high dose with placebo, respectively.",
+	                                    "",
+	                                    "H3: Period 2 primary hypothesis of no difference for endpoint (b) comparing drug (by pooling all patients on active treatment) with placebo.",
+	                                    "",
+	                                    "H4, H5: Period 1 key secondary hypotheses of no difference in the proportions comparing low and high dose with placebo, respectively.",
+	                                    "",
+	                                    "Literature: Maurer, W., & Bretz, F. (2013). Memory and other properties of multiple test procedures generated by entangled graphs. Statistics in medicine, 32(10), p. 1739-1753.", sep="\n")
 	
 	return(graph)
 }
@@ -921,7 +927,13 @@ Entangled2Maurer2012 <- function() {
 	
 	attr(graph, "description") <- paste("Graph from Maurer and Bretz 2012",
 			"",
-			"Literature: Maurer, W., & Bretz, F. (2013). Memory and other properties of multiple test procedures generated by entangled graphs. Statistics in medicine, 32(10), 1739-1753.", sep="\n")
+			"H1, H2: Period 1 primary hypotheses of no effect for endpoint (a) comparing low and high dose with placebo, respectively.",
+			"",
+			"H3: Period 2 primary hypothesis of no difference for endpoint (b) comparing drug (by pooling all patients on active treatment) with placebo.",
+			"",
+			"H4, H5: Period 1 key secondary hypotheses of no difference in the proportions comparing low and high dose with placebo, respectively.",
+			"",
+			"Literature: Maurer, W., & Bretz, F. (2013). Memory and other properties of multiple test procedures generated by entangled graphs. Statistics in medicine, 32(10), p. 1739-1753.", sep="\n")
 	
 	return(graph)
 }
