@@ -104,6 +104,7 @@ graphTest <- function(pvalues, weights = NULL, alpha = 0.05, G = NULL, cr = NULL
 		## get alpha vector and transition matrix/matrices
     if ("graphMCP" %in% class(graph)) {
 		  alphas <- graph@weights * alpha
+		  weights <- graph@weights
 		  G <- graph@m
     } else {
       G <- getMatrices(graph)
@@ -131,35 +132,45 @@ graphTest <- function(pvalues, weights = NULL, alpha = 0.05, G = NULL, cr = NULL
 		}
 		return(out)
 	} else { # non-parametric case		
-		if(is.list(G)){
-			nGraphs <- length(G)
-			G <- c(unlist(G))
-		} else {
-			nGraphs <- as.integer(1)
-		}
-		if(!is.matrix(pvalues)){
-			res <- .C("graphproc", h=double(nH), a=as.double(alphas), G=as.double(G),
-					as.double(pvalues), nH, as.double(G), as.integer(nGraphs),
-					as.integer(verbose))
-			out <- c(H = res$h)
-			attr(out, "last.alphas") <- res$a
-			attr(out, "last.G") <- matrix(res$G, ncol = nH)
-			return(out)
-		} else {
-			nCount <- as.integer(nrow(pvalues))
-			res <- .C("graphmult", h=double(nH*nCount), double(nH),
-					as.double(alphas), double(nGraphs*nH),
-					as.double(G), as.double(G), as.double(G),
-					as.double(pvalues), double(nH), nCount, nH,
-					as.integer(nGraphs), as.integer(verbose))
-			out <- matrix(res$h, nrow = nCount)
-			if(is.null(colnames(G))) {
-				colnames(out) <- paste("H", 1:nH, sep="")
+		if(is.list(G) || upscale==FALSE){
+		  if(is.list(G)) {
+		    nGraphs <- length(G)
+		    G <- c(unlist(G))
+		  } else {
+		    nGraphs <- 1
+		  }
+			if (upscale==TRUE) stop("Upscale=TRUE with list of graphs currently not supported")
+			if(!is.matrix(pvalues)){
+			  res <- .C("graphproc", h=double(nH), a=as.double(alphas), G=as.double(G),
+			            as.double(pvalues), nH, as.double(G), as.integer(nGraphs),
+			            as.integer(verbose), as.integer(upscale))
+			  out <- c(H = res$h)
+			  attr(out, "last.alphas") <- res$a
+			  attr(out, "last.G") <- matrix(res$G, ncol = nH)
+			  return(out)
 			} else {
-				colnames(out) <- colnames(G)
+			  nCount <- as.integer(nrow(pvalues))
+			  res <- .C("graphmult", h=double(nH*nCount), double(nH),
+			            as.double(alphas), double(nGraphs*nH),
+			            as.double(G), as.double(G), as.double(G),
+			            as.double(pvalues), double(nH), nCount, nH,
+			            as.integer(nGraphs), as.integer(verbose))
+			  out <- matrix(res$h, nrow = nCount)
+			  if(is.null(colnames(G))) {
+			    colnames(out) <- paste("H", 1:nH, sep="")
+			  } else {
+			    colnames(out) <- colnames(G)
+			  }
+			  return(out)
 			}
-			return(out)
 		}
+	  out <- matrix(0, nrow=0, ncol=dim(pvalues)[2])
+	  colnames(out) <- colnames(G)
+	  for (i in 1:(dim(pvalues)[1])) {
+	    adjP <- gMCP(new("graphMCP", m=G, weights=weights), pvalues[i,], upscale=upscale)@adjPValues
+	    out <- rbind(out, ifelse(adjP<=alpha,1,0))
+	  }
+	  return(out)
 	}
 }
 
